@@ -1,5 +1,8 @@
+from typing import Dict
+from typing import List
+from typing import Optional
+
 from pydantic import BaseModel
-from typing import Dict, List, Optional
 
 
 class QredoTransactionEvent(BaseModel):
